<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">
<html ng-app="solrAdminApp" ng-csp>
<!--
Licensed to the Apache Software Foundation (ASF) under one or more
contributor license agreements.  See the NOTICE file distributed with
this work for additional information regarding copyright ownership.
The ASF licenses this file to You under the Apache License, Version 2.0
(the "License"); you may not use this file except in compliance with
the License.  You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
-->

<head>
  <title>Solr Admin</title>

  <link rel="icon" type="image/x-icon" href="img/favicon.ico?_=${version}">
  <link rel="shortcut icon" type="image/x-icon" href="img/favicon.ico?_=${version}">

  <link rel="stylesheet" type="text/css" href="css/angular/angular-csp.css?_=${version}">
  <link rel="stylesheet" type="text/css" href="css/angular/common.css?_=${version}">
  <link rel="stylesheet" type="text/css" href="css/angular/analysis.css?_=${version}">
  <link rel="stylesheet" type="text/css" href="css/angular/schema-designer.css?_=${version}">
  <link rel="stylesheet" type="text/css" href="css/angular/security.css?_=${version}">
  <link rel="stylesheet" type="text/css" href="css/angular/cloud.css?_=${version}">
  <link rel="stylesheet" type="text/css" href="css/angular/cores.css?_=${version}">
  <link rel="stylesheet" type="text/css" href="css/angular/collections.css?_=${version}">
  <link rel="stylesheet" type="text/css" href="css/angular/dashboard.css?_=${version}">
  <link rel="stylesheet" type="text/css" href="css/angular/files.css?_=${version}">
  <link rel="stylesheet" type="text/css" href="css/angular/index.css?_=${version}">
  <link rel="stylesheet" type="text/css" href="css/angular/java-properties.css?_=${version}">
  <link rel="stylesheet" type="text/css" href="css/angular/logging.css?_=${version}">
  <link rel="stylesheet" type="text/css" href="css/angular/login.css?_=${version}">
  <link rel="stylesheet" type="text/css" href="css/angular/menu.css?_=${version}">
  <link rel="stylesheet" type="text/css" href="css/angular/plugins.css?_=${version}">
  <link rel="stylesheet" type="text/css" href="css/angular/documents.css?_=${version}">
  <link rel="stylesheet" type="text/css" href="css/angular/paramsets.css?_=${version}">
  <link rel="stylesheet" type="text/css" href="css/angular/query.css?_=${version}">
  <link rel="stylesheet" type="text/css" href="css/angular/stream.css?_=${version}">
  <link rel="stylesheet" type="text/css" href="css/angular/replication.css?_=${version}">
  <link rel="stylesheet" type="text/css" href="css/angular/schema.css?_=${version}">
  <link rel="stylesheet" type="text/css" href="css/angular/segments.css?_=${version}">
  <link rel="stylesheet" type="text/css" href="css/angular/threads.css?_=${version}">
  <link rel="stylesheet" type="text/css" href="css/angular/chosen.css?_=${version}">
  <link rel="stylesheet" type="text/css" href="css/angular/overview.css?_=${version}">
  <link rel="stylesheet" type="text/css" href="css/angular/sqlquery.css?_=${version}">
  <link rel="stylesheet" type="text/css" href="css/angular/ui-grid.min.css?_=${version}">
  <link rel="stylesheet" type="text/css" href="css/angular/jquery-ui.min.css?_=${version}">
  <link rel="stylesheet" type="text/css" href="css/angular/jquery-ui.structure.min.css?_=${version}">
  <link rel="stylesheet" type="text/css" href="css/angular/jstree.style.min.css?_=${version}">

  <meta http-equiv="x-ua-compatible" content="IE=9">
  <script src="libs/jquery-3.5.1.min.js?_=${version}"></script>
  <script src="libs/chosen.jquery.min.js?_=${version}"></script>
  <script src="libs/jstree.min.js?_=${version}"></script>
  <script src="libs/angular.min.js?_=${version}"></script>
  <script src="libs/angular-chosen.min.js?_=${version}"></script>
  <script src="libs/angular-resource.min.js?_=${version}"></script>
  <script src="libs/angular-route.min.js?_=${version}"></script>
  <script src="libs/angular-cookies.min.js?_=${version}"></script>
  <script src="libs/ngtimeago.js?_=${version}"></script>
  <script src="libs/highlight.js?_=${version}"></script>
  <script src="libs/d3.js?_=${version}"></script>
  <script src="libs/ui-grid.min.js?_=${version}"></script>
  <script src="libs/solr/index.js"></script>
  <script src="libs/jquery-ui.min.js?_=${version}"></script>
  <script src="libs/angular-utf8-base64.min.js?_=${version}"></script>
  <script src="libs/jssha-3.3.1-sha256.min.js?_=${version}"></script>
  <script src="js/angular/app.js?_=${version}"></script>
  <script src="js/angular/services.js?_=${version}"></script>
  <script src="js/angular/prometheus-parser.js?_=${version}"></script>
  <script src="js/angular/metrics-extractor.js?_=${version}"></script>
  <script src="js/angular/permissions.js?_=${version}"></script>
  <script src="js/angular/controllers/index.js?_=${version}"></script>
  <script src="js/angular/controllers/login.js?_=${version}"></script>
  <script src="js/angular/controllers/logging.js?_=${version}"></script>
  <script src="js/angular/controllers/cloud.js?_=${version}"></script>
  <script src="js/angular/controllers/collections.js?_=${version}"></script>
  <script src="js/angular/controllers/cores.js?_=${version}"></script>
  <script src="js/angular/controllers/threads.js?_=${version}"></script>
  <script src="js/angular/controllers/java-properties.js?_=${version}"></script>
  <script src="js/angular/controllers/alias-overview.js?_=${version}"></script>
  <script src="js/angular/controllers/core-overview.js?_=${version}"></script>
  <script src="js/angular/controllers/collection-overview.js?_=${version}"></script>
  <script src="js/angular/controllers/analysis.js?_=${version}"></script>
  <script src="js/angular/controllers/documents.js?_=${version}"></script>
  <script src="js/angular/controllers/paramsets.js?_=${version}"></script>
  <script src="js/angular/controllers/files.js?_=${version}"></script>
  <script src="js/angular/controllers/query.js?_=${version}"></script>
  <script src="js/angular/controllers/stream.js?_=${version}"></script>
  <script src="js/angular/controllers/plugins.js?_=${version}"></script>
  <script src="js/angular/controllers/replication.js?_=${version}"></script>
  <script src="js/angular/controllers/schema.js?_=${version}"></script>
  <script src="js/angular/controllers/schema-designer.js?_=${version}"></script>
  <script src="js/angular/controllers/security.js?_=${version}"></script>
  <script src="js/angular/controllers/segments.js?_=${version}"></script>
  <script src="js/angular/controllers/unknown.js?_=${version}"></script>
  <script src="js/angular/controllers/sqlquery.js?_=${version}"></script>


</head>
<body ng-controller="MainController">

  <div id="wrapper" scrollable-when-small>

    <div id="header">

      <a href="#/" id="solr"><span>Apache SOLR</span></a>

    </div>

    <div id="main" class="clearfix">

      <div class="header-message" id="init-failures" ng-show="showInitFailures" ng-cloak>

          <h2>SolrCore Initialization Failures</h2>
          <ul>
              <li ng-repeat="(core,error) in initFailures"><strong>{{core}}:</strong> {{error}}</li>
          </ul>
          <p>Please check your logs for more information</p>

      </div>

      <div class="header-message" id="authz-failures" ng-show="showAuthzFailures" ng-cloak>

        <h2>Permission failure</h2>
        <p>Your user does not have the necessary role(s) to perform this action.</p>

      </div>

      <div id="loading" class="loader universal-loader" loading-status-message>&nbsp;</div>

      <div id="connection-box" connection-message>
        <div id="connection-status-modal">
        </div>

        <div class="connection-status header-message">
          <h2>Connection to Solr lost</h2>
          <p>Please check the Solr instance.</p>
        </div>
        <div class="connection-status header-message" id="connection-status-recovered"  ng-show="connectionRecovered">
          <h2>Connection recovered...</h2>
          <p>Continuing to load data...</p>
        </div>
      </div>
      <div id="http-exception" class="header-message" ng-repeat="(url, exception) in exceptions" ng-cloak>
        <div class="exception">{{exception.msg}}</div>
      </div>

      <div id="content-wrapper">
        <div ng-view id="content">

        </div>
      </div>

      <div id="menu-wrapper">
        <div>

          <ul id="menu">
            <li id="environment" ng-class="environment" ng-show="showEnvironment" ng-style="environment_color !== undefined ? {'background-color': environment_color} : ''">{{ environment_label }}</li>

            <li id="login" class="global" ng-class="{active:page=='login'}" ng-show="http401 || currentUser"><p><a href="#/login">{{http401 ? "Login" : "Logout " + currentUser}}</a></p></li>

            <li id="index" class="global" ng-class="{active:page=='index'}"><p><a href="#/">Dashboard</a></p></li>

            <div ng-show="!http401">
              <li id="logging" class="global" ng-class="{active:page=='logging'}"><p><a href="#/~logging">Logging</a></p>
                <ul ng-show="showingLogging">
                  <li class="level" ng-class="{active:page=='logging-levels'}"><a href="#/~logging/level">Level</a></li>
                </ul>
              </li>

              <li id="security" class="global" ng-class="{active:page=='security'}"><p><a href="#/~security">Security</a></p></li>

              <li id="cloud" class="global optional" ng-show="isCloudEnabled" ng-class="{active:showingCloud}"><p><a href="#/~cloud">Cloud</a></p>
                <ul ng-show="showingCloud">
                  <li class="nodes" ng-class="{active:page=='cloud-nodes'}"><a href="#/~cloud?view=nodes">Nodes</a></li>
                  <li class="tree" ng-class="{active:page=='cloud-tree'}"><a href="#/~cloud?view=tree">Tree</a></li>
                  <li class="zkstatus" ng-class="{active:page=='cloud-zkstatus'}"><a href="#/~cloud?view=zkstatus">ZK Status</a></li>
                  <li class="graph" ng-class="{active:page=='cloud-graph'}"><a href="#/~cloud?view=graph">Graph</a></li>
                </ul>
              </li>

              <li ng-show="isCloudEnabled && isSchemaDesignerEnabled" id="schema-designer" class="global" ng-class="{active:page=='schema-designer'}"><p><a href="#/~schema-designer">Schema Designer</a></p></li>

              <li ng-show="isCloudEnabled" id="collections" class="global" ng-class="{active:page=='collections'}"><p><a href="#/~collections">Collections</a></p></li>
              <li ng-hide="isCloudEnabled" id="cores" class="global" ng-class="{active:page=='cores'}"><p><a href="#/~cores">Core Admin</a></p></li>

              <li id="java-properties" class="global" ng-class="{active:page=='java-props'}"><p><a href="#/~java-properties">Java Properties</a></li>

              <li id="threads" class="global" ng-class="{active:page=='threads'}"><p><a href="#/~threads">Thread Dump</a></p></li>

              <li id="new-ui" class="global"><p><a href="/solr/ui">Open New UI</a></p></li>
            </div>
          </ul>

          <div ng-show="!http401">
            <div id="collection-selector" ng-show="isCloudEnabled">
              <div id="has-collections" ng-show="collections.length!=0">
                <select placeholder-text-single="'Collection Selector'"
                        ng-model="currentCollection"
                        chosen
                        ng-change="showCollection(currentCollection)"
                        ng-options="collection.name for collection in aliases_and_collections"></select>
              </div>
              <p id="has-no-collections" ng-show="collections.length==0"><a href="#/~collections">
                No collections available
                <span>Go and create one</span>
              </a></p>
            </div>
            <div id="collection-menu" class="sub-menu" ng-show="currentCollection">
              <ul>
                <li class="overview" ng-show="currentCollection.type === 'collection'" ng-class="{active:page=='collection-overview'}"><a href="#/{{currentCollection.name}}/collection-overview"><span>Overview</span></a></li>
                <li class="overview" ng-show="currentCollection.type === 'alias'" ng-class="{active:page=='alias-overview'}"><a href="#/{{currentCollection.name}}/alias-overview"><span>Overview</span></a></li>
                <li class="analysis" ng-show="!isMultiDestAlias(currentCollection)" ng-class="{active:page=='analysis'}"><a href="#/{{currentCollection.name}}/analysis"><span>Analysis</span></a></li>
                <li class="documents" ng-show="!isMultiDestAlias(currentCollection)" ng-class="{active:page=='documents'}"><a href="#/{{currentCollection.name}}/documents"><span>Documents</span></a></li>
                <li class="paramsets" ng-show="!isMultiDestAlias(currentCollection)" ng-class="{active:page=='paramsets'}"><a href="#/{{currentCollection.name}}/paramsets"><span>Paramsets</span></a></li>
                <li class="files" ng-show="!isMultiDestAlias(currentCollection)" ng-class="{active:page=='files'}"><a href="#/{{currentCollection.name}}/files"><span>Files</span></a></li>
                <li class="query" ng-class="{active:page=='query'}"><a href="#/{{currentCollection.name}}/query"><span>Query</span></a></li>
                <li class="stream" ng-class="{active:page=='stream'}"><a href="#/{{currentCollection.name}}/stream"><span>Stream</span></a></li>
                <li class="sqlquery" ng-class="{active:page=='sqlquery'}"><a href="#/{{currentCollection.name}}/sqlquery"><span>SQL</span></a></li>
                <li class="schema" ng-show="!isMultiDestAlias(currentCollection)" ng-class="{active:page=='schema'}"><a href="#/{{currentCollection.name}}/schema"><span>Schema</span></a></li>
              </ul>
            </div>
            <div id="core-selector">
              <div id="has-cores" ng-show="cores.length!=0">
                <select placeholder-text-single="'Core Selector'"
                        ng-model="currentCore"
                        chosen
                        ng-change="showCore(currentCore)"
                        ng-options="core.name for core in cores"></select>
              </div>
              <p id="has-no-cores" ng-show="cores.length==0"><a href="#/~cores">
                No cores available
                <span>Go and create one</span>
              </a></p>
            </div>
            <div id="core-menu" class="sub-menu" ng-show="currentCore">
              <ul>
                <li class="overview" ng-class="{active:page=='overview'}"><a href="#/{{currentCore.name}}/core-overview"><span>Overview</span></a></li>
                <li ng-hide="isCloudEnabled" class="analysis" ng-class="{active:page=='analysis'}"><a href="#/{{currentCore.name}}/analysis"><span>Analysis</span></a></li>
                <li ng-hide="isCloudEnabled" class="documents" ng-class="{active:page=='documents'}"><a href="#/{{currentCore.name}}/documents"><span>Documents</span></a></li>
                <li ng-hide="isCloudEnabled" class="paramsets" ng-class="{active:page=='paramsets'}"><a href="#/{{currentCore.name}}/paramsets"><span>Paramsets</span></a></li>
                <li ng-hide="isCloudEnabled" class="files" ng-class="{active:page=='files'}"><a href="#/{{currentCore.name}}/files"><span>Files</span></a></li>
                <li class="ping" ng-class="{active:page=='ping'}"><a ng-click="ping()"><span>Ping</span><small class="qtime" ng-show="showPing"> (<span>{{pingMS}}ms</span>)</small></a></li>
                <li class="plugins" ng-class="{active:page=='plugins'}"><a href="#/{{currentCore.name}}/plugins"><span>Plugins / Stats</span></a></li>
                <li ng-hide="isCloudEnabled" class="query" ng-class="{active:page=='query'}"><a href="#/{{currentCore.name}}/query"><span>Query</span></a></li>
                <li ng-hide="isCloudEnabled" class="replication" ng-class="{active:page=='replication'}"><a href="#/{{currentCore.name}}/replication"><span>Replication</span></a></li>
                <li ng-hide="isCloudEnabled" class="schema" ng-class="{active:page=='schema'}"><a href="#/{{currentCore.name}}/schema"><span>Schema</span></a></li>
                <li class="segments" ng-class="{active:page=='segments'}"><a href="#/{{currentCore.name}}/segments"><span>Segments info</span></a></li>
              </ul>
            </div>
          </div>
        </div>
      </div>

      <div id="meta">

        <ul>

          <li class="documentation"><a href="https://solr.apache.org/guide/solr/latest/" target="_blank"><span>Documentation</span></a></li>
          <li class="query-syntax"><a href="https://solr.apache.org/guide/solr/latest/query-guide/query-syntax-and-parsers.html" target="_blank"><span>Solr Query Syntax</span></a></li>
          <li class="community"><a href="https://solr.apache.org/community.html" target="_blank"><span>Community</span></a></li>
          <li class="issues"><a href="https://issues.apache.org/jira/browse/SOLR" target="_blank"><span>Issue Tracker</span></a></li>
          <li class="chat"><a href="https://s.apache.org/solr-slack" target="_blank"><span>Slack</span></a></li>
          <li class="chat"><a href="https://web.libera.chat/?channels=#solr" target="_blank"><span>IRC</span></a></li>

        </ul>

      </div>

    </div>

  </div>

</body>
</html>
