/*

Licensed to the Apache Software Foundation (ASF) under one or more
contributor license agreements.  See the NOTICE file distributed with
this work for additional information regarding copyright ownership.
The ASF licenses this file to You under the Apache License, Version 2.0
(the "License"); you may not use this file except in compliance with
the License.  You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

*/
#content #designer
{
  position: relative;
}

#content #designer .loader
{
  background-position: 0 50%;
  padding-left: 21px;
}

#content #designer #designer-top
{
  padding: 0px;
}

#content #designer #tree-content
{
  overflow: auto;
  float: left;
  height: 520px;
  width: 275px;
  padding: 3px;
}
#content #designer #tree-node-content
{
  height: 560px;
  margin: 2px;
  overflow: hidden;
}

#content #designer .designer-left
{
  float: left;
  width: 380px;
  min-width: 380px; /* so the text area doesn't bleed over to the right */
  padding: 7px;
}

#content #designer .designer-middle
{
  float: left;
  width: 48%;
  padding: 7px;
  height: 585px;
}

#content #designer .designer-right
{
  padding: 7px;
  overflow: hidden;
}

#content #designer .query-tester-left
{
  float: left;
  width: 30%;
  padding: 7px;
}

#content #designer .query-tester-right
{
  padding: 7px;
  overflow: auto;
}

#content #designer .data
{
  padding-bottom: 12px;
  overflow: hidden;
}

#content #designer .data:hover
{
  overflow-x: auto;
}

#content #designer .data li
{
  padding-top: 3px;
  padding-bottom: 3px;
}

#content #designer .data li dt
{
  float: left;
  white-space: nowrap;
  width: 20%;
}

#content #designer .data li dd
{
  float: right;
  text-overflow: ellipsis;
  white-space: nowrap;
  width: 80%
}

#content #designer .data li dd.odd
{
  background-color: #f0f0f0;
}

#content #designer .data dt span
{
  background-position: 1px 50%;
  display: block;
  padding-left: 22px;
  font-weight: bold;
  text-align: left;
}

#content #designer #sample-docs h2 { background-image: url( ../../img/ico/document-text.png ); }
#content #designer #query-tester h2 { background-image: url( ../../img/ico/magnifier.png ); }
#content #designer #query-results h2 { background-image: url( ../../img/ico/documents-stack.png ); }
#content #designer #schema-editor h2 { background-image: url( ../../img/ico/book-open-text.png ); }
#content #designer #analysis h2 { background-image: url( ../../img/ico/property.png ); }

#content #designer #form
{
  margin-bottom: 10px;
}

#content #designer #form label
{
  cursor: pointer;
  display: block;
  margin-top: 5px;
}

#content #designer #field-form-left
{
  float: left;
  width: 45%;
  padding: 7px;
}

#content #designer #field-form-right
{
  margin-top: 8px;
  padding: 7px;
  overflow: hidden;
}

#content #designer .field-form
{
  display: block;
  padding: 5px;
}

#content #designer .field-form-right
{
  display: block;
  padding: 5px;
}

#content #designer .field-form-checkbox {
  margin-top: 10px;
  margin-left: 130px;
  display: block;
}

#content #designer .field-form-right label
{
  float: left;
  padding-top: 3px;
  padding-bottom: 3px;
  text-align: right;
  width: 120px;
  margin-right: 6px;
}

#content #designer #languages
{
  width: 125px;
}

#content #designer .checkbox
{
  text-align: left;
  padding-left: 3px;
}

#content #designer .actions
{
  margin-bottom: 5px;
}

#content #designer .actions form .error
{
  background-image: url( ../../img/ico/cross-button.png );
  background-position: 22% 1px;
  color: #c00;
  font-weight: bold;
}

#content #designer .actions form p
{
  padding-bottom: 8px;
}

#content #designer .actions form label
{
  float: left;
  padding-top: 3px;
  padding-bottom: 3px;
  text-align: right;
  width: 25%;
  margin-right: 6px;
}

#content #designer .actions #download-button span
{
  background-image: url( ../../img/ico/download-cloud.png );
}

#content #designer #schema-selector .left
{
  float: left;
  width: 405px;
}

#content #designer #schema-selector .middle
{
  float: left;
  width: 48%;
}

#content #designer #schema-selector .right
{
  text-align: right;
  overflow: hidden;
  margin-right: 10px;
}

#content #designer #schema-selector #apply
{
  float: right;
  text-align: right;
  width: 300px;
}

#content #designer #schema-selector a
{
  padding: 0;
  padding-left: 8px;
}

#content #designer #schema-selector select
{
  width: 150px;
}

#content #designer .actions form input,
#content #designer .actions form select,
#content #designer .actions form .buttons,
#content #designer .actions form .note span
{
  float: right;
  width: 71%;
}

#content #designer .actions form .note span
{
  padding-left: 3px;
  padding-right: 3px;
}

#content #designer .actions form .buttons
{
  padding-top: 10px;
}

#content #designer .actions form button.submit
{
  margin-right: 20px;
}

#content #designer .actions form button.submit span
{
  background-image: url( ../../img/ico/tick.png );
}

#content #designer .actions form button.reset span
{
  background-image: url( ../../img/ico/cross.png );
}

#content #designer .actions #add span
{
  background-image: url( ../../img/ico/plus-button.png );
}

#content #designer .actions #unload
{
  margin-right: 20px;
}

#content #designer .actions #unload span
{
  background-image: url( ../../img/ico/cross.png );
}

#content #designer .actions #reload span
{
  background-image: url( ../../img/ico/arrow-circle.png );
}

#content #designer .actions #rename span
{
  background-image: url( ../../img/ico/ui-text-field-select.png );
}

#content #designer .actions #swap span
{
  background-image: url( ../../img/ico/arrow-switch.png );
}

#content #designer .actions div.action
{
  z-index: 100;
  background-color: #fff;
  border: 1px solid #f0f0f0;
  box-shadow: 5px 5px 10px #c0c0c0;
  -moz-box-shadow: 5px 5px 10px #c0c0c0;
  -webkit-box-shadow: 5px 5px 10px #c0c0c0;
  position: absolute;
  left: 0px;
  top: 36px;
  padding: 10px;
  width: 320px;
}

/* Sample Documents */

#content #designer #analyze-buttons{
  float: right;
  margin-right: 12px;
}

#content #designer #query-buttons{
  margin-top: 20px;
  float: right;
  margin-right: 8px;
}

#content #designer #queryButton span
{
  background-image: url( ../../img/ico/magnifier.png );
}

#content #designer #analyze span
{
  background-image: url( ../../img/ico/gear.png );
}

#content #designer #document-container
{
  padding: 5px;
}

#content #designer #file-upload
{
  margin-bottom: 20px;
}

/* Section header bars */

#content #designer .bar-desc
{
  color: #4D4D4D;
  font-weight: normal;
  margin-left: 10px;
  white-space: pre;
}

#content #designer .bar-holder
{
  box-shadow: 5px 5px 10px #c0c0c0;
  -moz-box-shadow: 5px 5px 10px #c0c0c0;
  -webkit-box-shadow: 5px 5px 10px #c0c0c0;
  height: 35px;
}

#content #designer .bar-holder .bar
{
  height: 100%;
  position: relative;
}

#content #designer .bar-holder div .val
{
  border-right: 1px solid #f00;
  display: block;
  padding-right: 5px;
  position: absolute;
  right: 0;
  top: 35px;
  white-space: nowrap;
}

#content #designer .bar-holder .bar-max.bar
{
  background-color: #f0f0f0;
}

#content #designer .bar-holder .bar-max.val
{
  border-color: #f0f0f0;
  color: #8D8D8D;
}

#content #designer .bar-holder .bar-total.bar
{
  background-color: #c0c0c0;
}

#content #designer .bar-holder .bar-total.val
{
  border-color: #c0c0c0;
  color: #4D4D4D;
}

#content #designer .bar-holder .bar-used.bar
{
  background-color: #969696;
}

#content #designer .bar-holder .bar-used.val
{
  border-color: #969696;
  color: #969696;
}

#content #designer .bar-holder.bar-lvl-2 .bar-max.val { padding-top: 25px; }
#content #designer .bar-holder.bar-lvl-2 .bar-total.val { padding-top: 5px; }
#content #designer .bar-holder.bar-lvl-2 { margin-bottom: 45px; }

#content #designer .bar-holder.bar-lvl-3 .bar-max.val { padding-top: 45px; }
#content #designer .bar-holder.bar-lvl-3 .bar-total.val { padding-top: 25px; }
#content #designer .bar-holder.bar-lvl-3 .bar-used.val { padding-top: 5px; }
#content #designer .bar-holder.bar-lvl-3 { margin-bottom: 65px; }

#content #designer .analyzer,
#content #designer .analyzer li,
#content #designer .analyzer ul,
#content #designer .analyzer ul li
{
}

#content #designer .analyzer p,
#content #designer .analyzer dl
{
  float: left;
}

#content #designer .analyzer p
{
  margin-right: 5px;
  text-align: left;
  width: 100px;
  white-space: pre;
}

#content #designer .analyzer p a
{
  cursor: auto;
}

#content #designer .analyzer p a.analysis
{
  cursor: pointer;
  display: block;
}

#content #designer .analyzer p a.analysis span
{
  background-image: url( ../../img/ico/question-white.png );
  background-position: 0 50%;
  padding-left: 21px;
}

#content #designer .analyzer p a.analysis:hover span
{
  background-image: url( ../../img/ico/question.png );
  color: #008;
}

#content #designer .analyzer a
{
  cursor: pointer;
}

#content #designer .file-link
{
  cursor: pointer;
  color: #003eff;
  text-decoration-line: underline;
  text-decoration-color: #003eff;
}

#content #designer .analyzer .toggle
{
  background-image: url( ../../img/ico/chevron-small-expand.png );
  background-position: 100% 50%;
  cursor: pointer;
  display: block;
  padding-right: 21px;
}

#content #designer .analyzer .open .toggle
{
  background-image: url( ../../img/ico/chevron-small.png );
}

#content #designer .analyzer li
{
  border-top: 1px solid #f0f0f0;
  margin-top: 10px;
  padding-top: 10px;
  margin-left: 10px;
}

#content #designer .analyzer ul
{
  clear: left;
  margin-left: 25px;
  padding-top: 5px;
}

#content #designer .analyzer .open ul
{
  display: block;
}

#content #designer .analyzer ul li
{
  border-top: 1px solid #f8f8f8;
  margin-top: 5px;
  padding-top: 5px;
}

#content #designer .analyzer ul p
{
  color: #4D4D4D;
  margin-right: 5px;
  text-align: left;
  width: 80px;
}

#content #designer .analyzer ul dd
{
  margin-left: 10px;
}

#content #designer .analyzer ul dd
{
  background-image: url( ../../img/ico/document-list.png );
  background-position: 0 50%;
  color: #4D4D4D;
  padding-left: 21px;
}

#content #designer .analyzer ul dd.ico-0
{
  background-image: url( ../../img/ico/slash.png );
}

#content #designer .analyzer ul dd.ico-1
{
  background-image: url( ../../img/ico/tick.png );
}

#content #designer #field-top
{
  width: 100%;
}

#content #designer #field-top-left
{
  float: left;
  width: 240px;
  padding: 7px;
}

#content #designer #field-top-right
{
  display: contents;
}

#content #designer #tree-node-content form button.submit
{
  margin-left: 140px;
}

#content #designer #tree-node-content form button.submit span
{
  background-image: url( ../../img/ico/tick.png );
}

#content #designer #field-bottom
{
  float: left;
  width: 100%;
}

#content #designer #schema-actions {
  float: left;
  width: 99%;
}

#content #designer .schema-actions #addField { margin-right: 15px; }
#content #designer .schema-actions #addFieldType { margin-right: 15px; }

#content #designer .schema-actions #addField span { background-image: url( ../../img/ico/document-list.png ); }
#content #designer .schema-actions #addCopyField span { background-image: url( ../../img/ico/document-import.png ); }
#content #designer .schema-actions #addFieldType span { background-image: url( ../../img/ico/document-text.png ); }

#content #designer #updateSelected { float: right; margin-top:5px; }
#content #designer #updateSelected span { background-image: url( ../../img/ico/tick.png ); }
#content #designer #deleteSelected { margin-right: 0px; }
#content #designer #deleteSelected span { background-image: url( ../../img/ico/cross-button.png ); }

#content #designer #updateStatusMessage { color: darkgreen; float: right; margin-top: 5px; background-image: url( ../../img/ico/tick.png ); }
#content #designer #updateStatusMessage span { margin-left: 18px; }
#content #designer .working { font-style: italic; color: black !important; float: right; margin-top: 5px; background-image: url( ../../img/loader.gif ) !important; }

#content #designer .schema-actions div.action
{
  z-index: 100;
  background-color: #fff;
  border: 1px solid #f0f0f0;
  box-shadow: 5px 5px 10px #c0c0c0;
  -moz-box-shadow: 5px 5px 10px #c0c0c0;
  -webkit-box-shadow: 5px 5px 10px #c0c0c0;
  position: absolute;
  left: 448px;
  top: 31px;
  padding: 10px;
  width: 350px;
}

#content #designer .schema-actions div.copyfield
{
  z-index: 100;
  background-color: #fff;
  border: 1px solid #f0f0f0;
  box-shadow: 5px 5px 10px #c0c0c0;
  -moz-box-shadow: 5px 5px 10px #c0c0c0;
  -webkit-box-shadow: 5px 5px 10px #c0c0c0;
  position: absolute;
  left: 700px;
  top: 31px;
  padding: 10px;
  width: 350px;
}


#content #designer .schema-actions p
{
  padding-bottom: 8px;
}

#content #designer .schema-actions label
{
  margin-right: 6px;
  float: left;
  padding-top: 3px;
  padding-bottom: 3px;
  text-align: right;
  width: 25%;
}

#content #designer .schema-actions input,
#content #designer .schema-actions select,
#content #designer .schema-actions .buttons,
#content #designer .schema-actions .note span
{
  float: right;
  width: 71%;
}

#content #designer #add-errors
{
  float: left;
  margin-top:10px;
  margin-bottom: 10px;
  min-height: 30px;
}

#content #designer #add-errors .error
{
  background-image: url( ../../img/ico/cross-button.png );
  background-position: 10px 1px;
  color: #c00;
  font-weight: bold;
}

#content #designer #add-errors .error span
{
  margin-left: 30px;
}

#content #designer .schema-actions .chosen-container
{
  width: 71% !important;
}

#content #designer .chosen-container {
  width: 100%;
}
#content #designer .chosen-drop input,
#content #designer .chosen-results {
  width: 100% !important;
}

#content #designer .schema-actions label.checkbox {
  margin-left: 27%;
  text-align: left;
  width: 73%;
  padding: 0px;
  margin-top: 0px;
}
#content #designer .schema-actions .checkbox input {
  float: none;
  width: auto;
}

#content #designer .add_showhide {
  background-image: url( ../../img/ico/chevron-small-expand.png );
  background-position: 100% 50%;
  cursor: pointer;
  padding-right: 21px;
}

#content #designer .add_showhide.open {
  background-image: url( ../../img/ico/chevron-small.png );
}

#content #designer #schema-actions button span
{
  background-image: url( ../../img/ico/cross.png );
}
#content #designer #schema-actions button.submit span
{
  background-image: url( ../../img/ico/tick.png );
}

#content #designer #field-analysis
{
  margin-bottom: 0;
  overflow: auto;
  max-height: 135px;
}

#content #designer #analysis #field-analysis-holder
{
  width: 100%;
  padding: 5px;
  max-height: 480px;
  overflow: auto;
}

#content #designer #analysis #field-analysis-holder #field-analysis-form
{
  width: 100%;
  padding: 5px;
}

#content #designer #analysis .settings
{
  clear: both;
  padding: 5px;
}

#content #designer #analysis select
{
  width: 200px;
}

#content #designer #analysis .settings select.loader
{
  background-position: 3px 50%;
  padding-left: 21px;
}

#content #designer #analysis .settings select optgroup
{
  font-style: normal;
  padding: 5px;
}

#content #designer #analysis .settings select option
{
  padding-left: 10px;
}

#content #designer #analysis .settings label
{
  display: block;
  width: 150px;
}

#content #designer #analysis .settings textarea
{
  display: block;
}

#content #designer #analysis .settings
{
  float: left;
  margin-right: 0.5%;
}

#content #designer #analysis .analysis-error
{
  background-color: #f00;
  background-image: url( ../../img/ico/construction.png );
  background-position: 10px 50%;
  color: #fff;
  font-weight: bold;
  margin-bottom: 20px;
  padding: 10px;
  padding-left: 35px;
}

#content #designer #analysis .analysis-error .head a
{
  color: #fff;
  cursor: auto;
}

#content #designer #analysis #analysis-result
{
  width: 100%;
  float: left;
  overflow: auto;
}

#content #designer #analysis #analysis-result .index
{
  background-color: #fff;
  padding-top: 20px;
}

#content #designer #analysis #analysis-result table
{
  border-collapse: collapse;
}

#content #designer #analysis #analysis-result td
{
  vertical-align: top;
  white-space: nowrap;
}

#content #designer #analysis #analysis-result td.part.analyzer div,
#content #designer #analysis #analysis-result td.part.spacer .holder,
#content #designer #analysis #analysis-result td td td
{
  padding-top: 1px;
  padding-bottom: 1px;
}

#content #designer #analysis #analysis-result.verbose_output td.legend
{
  display: table-cell;
}

#content #designer #analysis #analysis-result.verbose_output td.data tr.verbose_output
{
  display: table-row;
}

#content #designer #analysis #analysis-result .match
{
  background-color: #F0D9C3;
}

#content #designer #analysis #analysis-result td.part
{
  padding-bottom: 10px;
}

#content #designer #analysis #analysis-result td.part.analyzer div
{
  border-right: 1px solid #f0f0f0;
  padding-right: 10px;
}

#content #designer #analysis #analysis-result td.part.analyzer abbr
{
  color: #4D4D4D;
}

#content #designer #analysis #analysis-result td.part.legend .holder,
#content #designer #analysis #analysis-result td.part.data .holder
{
  padding-left: 10px;
  padding-right: 10px;
  border-right: 1px solid #c0c0c0;
}

#content #designer #analysis #analysis-result td.part.legend td
{
  color: #4D4D4D;
}

#content #designer #analysis #analysis-result td.part.legend .holder
{
  border-right-color: #f0f0f0;
}

#content #designer #analysis #analysis-result td.part.data:last-child .holder
{
  padding-right: 0;
  border-right: 0;
}

#content #designer #analysis #analysis-result td.details
{
  padding-left: 10px;
  padding-right: 10px;
  border-left: 1px solid #f0f0f0;
  border-right: 1px solid #f0f0f0;
}

#content #designer #analysis #analysis-result td.details:first-child
{
  padding-left: 0;
  border-left: 0;
}

#content #designer #analysis #analysis-result td.details:last-child
{
  padding-right: 0;
  border-right: 0;
}

#content #designer #analysis #analysis-result td.details tr.empty td
{
  color: #f0f0f0;
}

#content #designer #analysis #analysis-result td.details tr.raw_bytes td
{
  letter-spacing: -1px;
}

#content #designer #analysis #analysis-result .part table table td
{
  border-top: 1px solid #f0f0f0;
}

#content #designer #analysis #analysis-result .part table table tr:first-child td
{
  border-top: 0;
}

#content #designer #analysis #field-analysis h2 { background-image: url( ../../img/ico/receipt.png ); }
#content #designer #analysis .analysis-result h2 { background-image: url( ../../img/ico/receipt-invoice.png ); }

#content #designer #schema-root-details
{
  min-height: 360px;
  padding: 7px;
}

#content #designer #schema-root-details #unique_key
{
  width: 150px;
}

#content #designer #schema-root-details .note span
{
  float: right;
  padding-left: 18px;
}

#content #designer #schema-root-details .error
{
  background-image: url( ../../img/ico/cross-button.png );
  background-position: 0px 2px;
  color: #c00;
  font-weight: bold;
}

/* diff dialog */
#content #designer div.diff
{
  z-index: 100;
  position: absolute;
  background-color: #fff;
  border: 1px solid #f0f0f0;
  box-shadow: 5px 5px 10px #c0c0c0;
  -moz-box-shadow: 5px 5px 10px #c0c0c0;
  -webkit-box-shadow: 5px 5px 10px #c0c0c0;
  top: 31px;
  left: 650px;
  padding: 10px;
  width: 600px;
  overflow: auto;
  min-height: 370px;
  max-height: 600px;
}

#content #designer table.diff {
  font-family: arial, sans-serif;
  border-collapse: collapse;
  width: 100%;
  display: inline-block;
  overflow: auto;
}

#content #designer table.diff th {
  font-family: arial, sans-serif;
  font-weight: bold;
  min-width: 100px;
}

#content #designer p.diff-text {
  margin-top: 15px;
  margin-bottom: 5px;
  font-size: medium;
  font-weight: bold;
}

#content #designer p.diff-field-name {
  margin-top: 5px;
  margin-bottom: 15px;
  font-size: small;
  font-weight: bold;
}

#content #designer li.element
{
  border: 1px solid #f0f0f0;
  box-shadow: 5px 5px 10px #c0c0c0;
  -moz-box-shadow: 5px 5px 10px #c0c0c0;
  -webkit-box-shadow: 5px 5px 10px #c0c0c0;
  margin-top: 5px;
  margin-bottom: 15px;
}

#content #designer .actions .diff-buttons {
  margin-right: 15px;
  float: right;
  width: 48%;
}

#content #designer p.old-value {
  color: indianred;
  text-decoration: line-through;
}

#content #designer p.rem-value {
  color: indianred;
}

#content #designer p.new-value {
  color: green;
}

/* publish dialog */
#content #designer .actions div.publish
{
  z-index: 100;
  position: absolute;
  background-color: #fff;
  border: 1px solid #f0f0f0;
  box-shadow: 5px 5px 10px #c0c0c0;
  -moz-box-shadow: 5px 5px 10px #c0c0c0;
  -webkit-box-shadow: 5px 5px 10px #c0c0c0;
  top: 31px;
  left: 1150px;
  padding: 10px;
  width: 380px;
  height: 430px;
}

#content #designer .actions .publish-button {
  margin-right: 15px;
}

#content #designer .actions .publish-button span
{
  background-image: url( ../../img/ico/disk-black.png );
}

#content #designer .actions .diff-button {
  margin-right: 15px;
}

#content #designer .actions .diff-button span {
  background-image: url( ../../img/ico/document-convert.png );
}

#content #designer .actions button.reset span
{
  background-image: url( ../../img/ico/cross.png );
}

#content #designer #publish-dialog-note {
  margin-bottom: 15px;
}

#content #designer #publish-new-coll {
  margin-top: 15px;
  margin-bottom: 10px;
}

#content #designer .publish-buttons
{
  margin-top: 20px;
  float: right;
  width: 48%;
}

#content #designer #publish-affected {
  overflow: auto;
  height: 60px;
}

#content #designer #reload-form {
  height: 20px;
}

#content #designer #file-node-text {
  display:block;
}

#content #designer #file-node {
  padding: 7px;
}

#content #designer #save-file span {
  background-image: url( ../../img/ico/disk-black.png );
}

#content #designer #results-tree-left {
  float: left;
  width: 330px;
  overflow: auto;
  height: 350px;
}

#content #designer #results-tree-right {
  max-width: 800px;
  float: left;
  overflow: auto;
  height: 350px;
}

#content #designer #save-file-buttons {
  margin-top: 15px;
  margin-right: 5px;
  display: block;
  float: right;
}

#content #designer #copy_dest {
  width: 300px;
}

#content #designer .hit-field {
  padding: 3px;
  width: 120px;
}

#content #designer .hit-value {
  padding: 3px;
  word-wrap: break-word;
  max-width: 700px;
}

#content #designer #leaf-node .error
{
  background-image: url( ../../img/ico/cross-button.png );
  background-position: 0px 2px;
  color: #c00;
  font-weight: bold;
}

#content #designer #leaf-node .error span
{
  padding-left: 18px;
}

#content #designer #sample-docs .note
{
  background-image: url( ../../img/ico/information.png );
  background-position: 0px 2px;
  color: #008;
  font-weight: bold;
}

#content #designer #confirm-dialog
{
  width: 350px;
  height: 250px;
}

#content #designer #confirm-dialog .warn span
{
  padding-left: 18px;
}

#content #designer #confirm-dialog .warn
{
  background-image: url( ../../img/ico/exclamation-button.png );
  background-position: 0px 2px;
  font-weight: bold;
}

#content #designer #confirm-dialog #confirm-edit span {
  background-image: url( ../../img/ico/tick.png );
}

#content #designer #confirm-dialog #confirm-colls {
  margin-top: 15px;
  margin-bottom: 15px;
}


#content #designer #sample-docs .note span
{
  padding-left: 18px;
}

#content #designer .information
{
  display: block;
  height: 40px;
}

#content #designer #field-bottom fieldset.common
{
  margin-top: 10px;
}

#content #designer #field-bottom fieldset legend,
#content #designer #field-bottom .optional.expanded legend
{
  display: block;
  margin-left: 10px;
  padding: 0px 5px;
}

#content #designer #field-bottom fieldset legend label
{
  margin-top: 0;
}

#content #designer #query-form select
{
  width: 150px;
}

#content #designer #selected-hit {
  padding: 5px;
}

#content #designer tr.odd
{
  background-color: #f8f8f8;
}

#content #designer .help
{
  font-weight: normal !important;
  position: relative;
}

#content #designer .help div.help
{
  z-index: 200;
  background-color: #FCF0AD;
  border: 1px solid #f0f0f0;
  box-shadow: 5px 5px 10px #c0c0c0;
  -moz-box-shadow: 5px 5px 10px #c0c0c0;
  -webkit-box-shadow: 5px 5px 10px #c0c0c0;
  position: absolute;
  left: 0px;
  top: 0px;
  padding: 6px;
  width: 340px;
}

#content #designer .help div.help-wide
{
  z-index: 200;
  background-color: #FCF0AD;
  border: 1px solid #f0f0f0;
  box-shadow: 5px 5px 10px #c0c0c0;
  -moz-box-shadow: 5px 5px 10px #c0c0c0;
  -webkit-box-shadow: 5px 5px 10px #c0c0c0;
  position: absolute;
  left: -90px;
  top: 0px;
  padding: 6px;
  width: 420px;
}

#content #designer .help div.help-wider
{
  z-index: 200;
  background-color: #FCF0AD;
  border: 1px solid #f0f0f0;
  box-shadow: 5px 5px 10px #c0c0c0;
  -moz-box-shadow: 5px 5px 10px #c0c0c0;
  -webkit-box-shadow: 5px 5px 10px #c0c0c0;
  position: absolute;
  left: 0px;
  top: 0px;
  padding: 6px;
  width: 430px;
}

#content #designer .help div.help-top
{
  z-index: 200;
  background-color: #FCF0AD;
  border: 1px solid #f0f0f0;
  box-shadow: 5px 5px 10px #c0c0c0;
  -moz-box-shadow: 5px 5px 10px #c0c0c0;
  -webkit-box-shadow: 5px 5px 10px #c0c0c0;
  position: absolute;
  left: 0px;
  top: -200px;
  padding: 6px;
  width: 420px;
}

#content #designer .help-anchor
{
  margin-top: 7px;
  margin-left: 18px;
  margin-bottom: 10px;
}

#content #designer .help-anchor a
{
  color: #003eff;
  text-decoration-line: underline;
  text-decoration-color: #003eff;
}

#content #designer .help-ico {
  margin-left: 3px;
  margin-top: 3px;
}

#content #designer #analysis .verbose_output
{
  padding: 3px;
  float: left;
  margin-left: 260px;
}

#content #designer #analysis .verbose_output a
{
  background-image: url( ../../img/ico/ui-check-box-uncheck.png );
  background-position: 0 50%;
  color: #4D4D4D;
  display: block;
  padding-left: 21px;
}

#content #designer #analysis .verbose_output.active a
{
  background-image: url( ../../img/ico/ui-check-box.png );
}

#content #designer #file-node .error
{
  background-image: url( ../../img/ico/cross-button.png );
  color: #c00;
  font-weight: bold;
}

#content #designer #file-node .error span
{
  margin-left: 20px;
}

#content #designer .field-top-form {
  margin-bottom: 7px;
  width: 300px;
}

#content #designer .field-top-form label {
  text-align: right;
  margin-right: 5px;
  width: 150px;
}

#content #designer .field-top-form select
{
  display: block;
  width: 150px;
}

#content #designer .warn-dialog
{
  z-index: 200;
  background-color: #f0f0f0;
  border: 1px solid #a0a0a0;
  box-shadow: 5px 5px 10px #c0c0c0;
  -moz-box-shadow: 5px 5px 10px #c0c0c0;
  -webkit-box-shadow: 5px 5px 10px #c0c0c0;
  position: absolute;
  left: 350px;
  top: 95px;
  padding: 20px;
  width: 450px;
}

#content #designer #warn-dialog #warn-dialog-buttons {
  float: right;
}

#content #designer #warn-dialog .warn-button {
  margin-right: 15px;
}

#content #designer #warn-dialog .warn-button span
{
  background-image: url( ../../img/ico/tick.png );
}

#content #designer .error-dialog
{
  z-index: 200;
  background-color: #f0f0f0;
  border: 1px solid #c00;
  box-shadow: 5px 5px 10px #c0c0c0;
  -moz-box-shadow: 5px 5px 10px #c0c0c0;
  -webkit-box-shadow: 5px 5px 10px #c0c0c0;
  position: absolute;
  left: 350px;
  top: 95px;
  padding: 20px;
  width: 450px;
}

#content #designer #error-dialog #error-dialog-buttons {
  float: right;
}

#content #designer #error-dialog .error-button {
  margin-right: 15px;
}

#content #designer #error-dialog .error-button span
{
  background-image: url( ../../img/ico/tick.png );
}

#content #designer #error-dialog .reload-error-button {
  margin-right: 15px;
}

#content #designer #error-dialog .reload-error-button span
{
  background-image: url( ../../img/ico/arrow-circle.png );
}

#content #designer #error-dialog-note {
  color: #c00;
  font-weight: bold;
  margin-bottom: 15px;
}

#content #designer #error-dialog-details {
  min-height: 80px;
  margin-bottom: 15px;
}

#content #designer #edit-analysis-json-link {
  margin-top: 10px;
  float: right;
}

#content #designer #edit-analysis-json-link a {
  cursor: pointer;
  color: #003eff;
  text-decoration-line: underline;
  text-decoration-color: #003eff;
}

#content #designer #tree-filters {
  font-size: 11px;
  max-width: 400px;
  overflow: hidden;
  margin-top: 2px;
  margin-bottom: 6px;
}

#content #designer #tree-filters-cat {
  max-width: 70px;
  font-size: 11px;
}

#content #designer #tree-filters-options {
  max-width: 90px;
  font-size: 11px;
}

#content #designer #copy_schema {
  width: 200px;
}

#content #designer #currentSchemaLabel {
  font-weight: bold;
  margin-top: 2px;
}

#content #designer #treeFilterFeatureEnabledSpan {
  display: inline;
  font-size: 11px;
}

#content #designer #treeFilterFeatureEnabledSpan input {
  padding: 0px;
  margin-top: 4px;
}

#content #designer .container-node {
  max-height: 540px;
  overflow: auto;
}


#content #designer .prop {
  border-bottom: 1px solid #dddddd;
  padding: 3px;
  text-align: left;
  min-width: 80px;
  word-wrap: break-word;
  max-width: 140px;
}

#content #designer .prop-flag {
  border-bottom: 1px solid #dddddd;
  padding: 3px;
  text-align: center;
}

#content #designer .prop-hdr {
  border-bottom: 1px solid #dddddd;
  padding: 3px;
  font-weight: bold;
  text-align: left;
  min-width: 80px;
  word-wrap: break-word;
  max-width: 140px;
}

#content #designer .prop-hdr-flag {
  border-bottom: 1px solid #dddddd;
  padding: 3px;
  font-weight: bold;
  text-align: center;
  min-width: 65px;
}

#content #designer #editDocumentsToolbar { float: right; margin-top:0px; margin-left:20px; }
#content #designer #editDocuments span { background-image: url( ../../img/ico/pencil.png ); }

#content #designer .help div.help-small
{
  z-index: 200;
  background-color: #FCF0AD;
  border: 1px solid #f0f0f0;
  box-shadow: 5px 5px 10px #c0c0c0;
  -moz-box-shadow: 5px 5px 10px #c0c0c0;
  -webkit-box-shadow: 5px 5px 10px #c0c0c0;
  position: absolute;
  left: -120px;
  top: 0px;
  padding: 6px;
  width: 250px;
}


