<!--
Licensed to the Apache Software Foundation (ASF) under one or more
contributor license agreements.  See the NOTICE file distributed with
this work for additional information regarding copyright ownership.
The ASF licenses this file to You under the Apache License, Version 2.0
(the "License"); you may not use this file except in compliance with
the License.  You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
-->
<div id="query" class="clearfix">

  <div id="form">
    <form>
      <label for="qt" title="Request handler in solrconfig.xml.">
        <a rel="help">Request-Handler (qt)</a>
      </label>
      <input type="text" ng-model="qt" id="qt" placeholder="/select" value="/select" title="Request handler in solrconfig.xml.">

      <fieldset class="common">
        <legend>common</legend>
        <div class="fieldset">

        <label for="q" title="The query string.">
          q
        </label>
        <textarea name="q" ng-model="val['q']" id="q" title="The query string.">*:*</textarea>

        <label for="qOp" title="The query operator.">
          q.op
        </label>
        <select ng-model="val['q.op']" id="qOp" name="q.op" title="The query operator.">
          <option value="AND">AND</option>
          <option value="OR">OR</option>
        </select>

        <label for="fq" title="Filter query.">
          <a rel="help">fq</a>
        </label>
        <div class="multiple" id="fq">
          <div class="row clearfix" ng-repeat="filter in filters">
            <input type="text" ng-model="filter.fq" name="fq" title="Filter query.">
            <div class="buttons">
              <a class="rem" ng-click="removeFilter($index)"><span></span></a>
              <a class="add" ng-click="addFilter($index)"><span></span></a>
            </div>
          </div>
        </div>

        <label for="sort" title="Sort field or function with asc|desc.">
          <a rel="help">sort</a>
        </label>
        <input type="text" ng-model="val['sort']" id="sort" name="sort" title="Sort field or function with asc|desc.">

        <label for="start" title="Number of leading documents to skip and number of documents to return after 'start'. (Integers)">
          <a rel="help">start</a>,
          <a rel="help">rows</a>
        </label>
        <div class="clearfix">
          <input type="text" name="start" ng-model="val['start']" id="start" placeholder="0" pattern="[0-9]+" title="Number of leading documents to skip. (Integer)">
          <input type="text" name="rows" ng-model="val['rows']" id="rows" placeholder="10" pattern="[0-9]+" title="Number of documents to return after 'start'. (Integer)">
        </div>

        <label for="fl" title="Field list, comma separated.">
          <a rel="help">fl</a>
        </label>
        <input type="text" ng-model="val['fl']" name="fl" id="fl" value="" title="Field list, comma separated.">

        <label for="df" title="Default search field">
          <a rel="help">df</a>
        </label>
        <input type="text" ng-model="val['df']" name="df" id="df" value="" title="Default search field">

        <label for="useParams">paramset(s)</label>
        <select id="useParams"
          ng-model="useParams"
          title="The paramsets to apply to the query."
          chosen
          multiple
          data-placeholder="Select paramset(s)..."
          ng-options="item for item in paramsetList"><option value=""></option></select>

        <label for="wt" title="The writer type (response format).">
          <a rel="help">wt</a>
        </label>
        <select name="wt" ng-model="val['wt']" id="wt" title="The writer type (response format).">
          <option ng-selected="selected" value=''>------</option>
          <option>json</option>
          <option>xml</option>
          <option>python</option>
          <option>ruby</option>
          <option>php</option>
          <option>csv</option>
        </select>

        <label for="indent" class="checkbox" title="Enable indenting of results.">
          <input type="checkbox" ng-model="val['indent']" name="indent" id="indent" title="Enable indenting of results." ng-true-value="true" ng-false-value="false">
          indent on
        </label>

        </div>
      </fieldset>

      <fieldset class="debugQuery optional">
        <legend>
          <label for="debugQuery" class="checkbox" title="Show timing and diagnostics.">
            <input type="checkbox" ng-model="val['debugQuery']" name="debugQuery" id="debugQuery" value="true">
            debugQuery
          </label>
        </legend>
        <div class="fieldset" ng-show="val['debugQuery']">

        <label for="debug_explain_structured" class="checkbox" title="Show Score explanations as nested structures.">
          <input type="checkbox" ng-model="val['debug.explain.structured']" name="debug.explain.structured" id="debug_explain_structured" value="true">
          debug.explain.structured
        </label>

        </div>
      </fieldset>

      <fieldset class="dismax optional">
        <legend>
          <label for="defType" class="checkbox" title="Choose defType">
            defType
            <select ng-model="val['defType']" name="defType" id="defType">
              <option ng-selected="selected" value=''>------</option>
              <option value="lucene">lucene</option>
              <option value="dismax">dismax</option>
              <option value="edismax">edismax</option>
            </select>
          </label>
        </legend>

        <div class="fieldset" ng-show="val['defType']=='dismax' || val['defType']=='edismax'">
          <label for="q_alt" title="Alternate query when 'q' is absent.">q.alt</label>
          <input type="text" ng-model="val['q.alt']" name="q.alt" id="q_alt"  title="Alternate query when 'q' is absent.">

          <label for="qf" title="Query fields with optional boosts.">qf</label>
          <input type="text" ng-model="val['qf']" name="qf" id="qf" title="Query fields with optional boosts.">

          <label for="mm" title="Min-should-match expression.">mm</label>
          <input type="text" ng-model="val['mm']" name="mm" id="mm" title="Min-should-match expression.">

          <label for="pf" title="Phrase boosted fields.">pf</label>
          <input type="text" ng-model="val['pf']" name="pf" id="pf" title="Phrase boosted fields.">

          <label for="ps" title="Phrase boost slop.">ps</label>
          <input type="text" ng-model="val['ps']" name="ps" id="ps" title="Phrase boost slop.">

          <label for="qs" title="Query string phrase slop.">qs</label>
          <input type="text" ng-model="val['qs']" name="qs" id="qs" title="Query string phrase slop.">

          <label for="tie" title="Score tie-breaker. Try 0.1.">tie</label>
          <input type="text" ng-model="val['tie']" name="tie" id="tie" title="Score tie-breaker. Try 0.1.">

          <label for="bq" title="Boost query.">bq</label>
          <input type="text" ng-model="val['bq']" name="bq" id="bq" title="Boost query.">

          <label for="bf" title="Boost function (added).">bf</label>
          <input type="text" ng-model="val['bf']" name="bf" id="bf" title="Boost function (added).">
          <div ng-show="val['defType']=='edismax'">
            <label for="uf" title="User Fields">uf</label>
            <input type="text" ng-model="val['uf']" name="uf" id="uf" title="User Fields">

            <label for="pf2" title="bigram phrase boost fields">pf2</label>
            <input type="text" ng-model="val['pf2']" name="pf2" id="pf2" title="bigram phrase boost fields">

            <label for="pf3" title="trigram phrase boost fields">pf3</label>
            <input type="text" ng-model="val['pf3']" name="pf3" id="pf3" title="trigram phrase boost fields">

            <label for="ps2" title="phrase slop for bigram phrases">ps2</label>
            <input type="text" ng-model="val['ps2']" name="ps2" id="ps2" title="phrase slop for bigram phrases">

            <label for="ps3" title="phrase slop for trigram phrases">ps3</label>
            <input type="text" ng-model="val['ps3']" name="ps3" id="ps3" title="phrase slop for trigram phrases">

            <label for="boost" title="multiplicative boost function">boost</label>
            <input type="text" ng-model="val['boost']" name="boost" id="boost" title="multiplicative boost function">

            <label for="stopwords" class="checkbox" title="remove stopwords from mandatory 'matching' component">
              <input type="checkbox" ng-model="val['stopwords']" name="stopwords" id="stopwords">
              stopwords
            </label>

            <label for="lowercaseOperators" class="checkbox" title="Enable lower-case 'and' and 'or' as operators">
              <input type="checkbox" ng-model="val['lowercaseOperators']" name="lowercaseOperators" id="lowercaseOperators">
              lowercaseOperators
            </label>
          </div>
        </div>
      </fieldset>

      <fieldset class="hl optional">
        <legend>
          <label for="hl" class="checkbox" title="Enable highlighting.">
            <input type="checkbox" ng-model="val['hl']" name="hl" id="hl" value="true">
            hl
          </label>
        </legend>
        <div class="fieldset" ng-show="val['hl']">

        <label for="hl_fl" title="Fields to highlight on.">hl.fl</label>
        <input type="text" ng-model="val['hl.fl']" name="hl.fl" id="hl_fl" value="" title="Fields to highlight on.">

        <div class="fieldset" ng-show="val['hl.method']=='original'">
          <label for="hl_simple_pre">hl.simple.pre</label>
          <input type="text" ng-model="val['hl.simple.pre']" name="hl.simple.pre" id="hl_simple_pre" value="<em>">

          <label for="hl_simple_post">hl.simple.post</label>
          <input type="text" ng-model="val['hl.simple.post']"  name="hl.simple.post" id="hl_simple_post" value="</em>">
        </div>

        <div class="fieldset" ng-show="val['hl.method']=='unified' || val['hl.method']=='fastVector'">
          <label for="hl_tag_pre">hl.tag.pre</label>
          <input type="text" ng-model="val['hl.tag.pre']" name="hl.tag.pre" id="hl_tag_pre" value="<em>">

          <label for="hl_tag_post">hl.tag.post</label>
          <input type="text" ng-model="val['hl.tag.post']"  name="hl.tag.post" id="hl_tag_post" value="</em>">
        </div>

        <label for="hl_requireFieldMatch" class="checkbox">
          <input type="checkbox" ng-model="val['hl.requireFieldMatch']" name="hl.requireFieldMatch" id="hl_requireFieldMatch" value="true">
          hl.requireFieldMatch
        </label>

        <label for="hl_usePhraseHighlighter" class="checkbox">
          <input type="checkbox" ng-model="val['hl.usePhraseHighLighter']" name="hl.usePhraseHighlighter" id="hl_usePhraseHighlighter" value="true">
          hl.usePhraseHighlighter
        </label>

        <label for="hl_highlightMultiTerm" class="checkbox">
          <input type="checkbox" ng-model="val['hl.highlightMultiTerm']" name="hl.highlightMultiTerm" id="hl_highlightMultiTerm" value="true">
          hl.highlightMultiTerm
        </label>

        <label for="hl_q">hl.q</label>
        <input type="text" ng-model="val['hl.q']" name="hl.q" id="hl_q" value="">

        <label for="hl_qparser">hl.qparser</label>
        <input type="text" ng-model="val['hl.qparser']" name="hl.qparser" id="hl_qparser" value="">

        <label for="hl_snippets">hl.snippets</label>
        <input type="text" ng-model="val['hl.snippets']" name="hl.snippets" id="hl_snippets" value="">

        <label for="hl_fragsize">hl.fragsize</label>
        <input type="text" ng-model="val['hl.fragsize']" name="hl.fragsize" id="hl_fragsize" value="">

        <label for="hl_encoder">hl.encoder</label>
        <input type="text" ng-model="val['hl.encoder']" name="hl.encoder" id="hl_encoder" value="">

        <label for="hl_maxAnalyzedChars">hl.maxAnalyzedChars</label>
        <input type="text" ng-model="val['hl.maxAnalyzedChars']" name="hl.maxAnalyzedChars" id="hl_maxAnalyzedChars" value="">

        <label for="hl_method" title="Choose hl.method">
          hl.method
          <select ng-model="val['hl.method']" name="hl_method" id="hl_method">
            <option ng-selected="selected" value=''>------</option>
            <option value="unified">unified</option>
            <option value="original">original</option>
            <option value="fastVector">fastVector</option>
          </select>
        </label>

        <p class="clearfix"><a ng-show="val['hl']" ng-click="showAdvanced=!showAdvanced">
          <span id="add_advanced" ng-class="{open: showAdvanced}">Show advanced</span></a></p>
        <div ng-show="showAdvanced">
          <div class="fieldset" ng-show="val['hl.method']=='unified'">
            <label for="hl_offsetSource" title="Choose hl.offsetSource">
              hl.offsetSource
              <select ng-model="val['hl.offsetSource']" name="hl.offsetSource" id="hl_offsetSource">
                <option ng-selected="selected" value=''>------</option>
                <option value="ANALYSIS">ANALYSIS</option>
                <option value="POSTINGS">POSTINGS</option>
                <option value="POSTINGS_WITH_TERM_VECTORS">POSTINGS_WITH_TERM_VECTORS</option>
                <option value="TERM_VECTORS">TERM_VECTORS</option>
              </select>
            </label>

            <label for="hl_fragAlignRatio">hl.fragAlignRatio</label>
            <input type="text" ng-model="val['hl.fragAlignRatio']" name="hl.fragAlignRatio" id="hl_fragAlignRatio">

            <label for="hl_fragsizeIsMinimum" class="checkbox">
              <input type="checkbox" ng-model="val['hl.fragsizeIsMinimum']" name="hl.fragsizeIsMinimum" id="hl_fragsizeIsMinimum" value="true">
              hl.fragsizeIsMinimum
            </label>

            <label for="hl_tag_ellipsis">hl.tag.ellipsis</label>
            <input type="text" ng-model="val['hl.tag.ellipsis']" name="hl.tag.ellipsis" id="hl_tag_ellipsis">

            <label for="hl_defaultSummary" class="checkbox">
              <input type="checkbox" ng-model="val['hl.defaultSummary']" name="hl.defaultSummary" id="hl_defaultSummary">
              hl.defaultSummary
            </label>

            <label for="hl_score_k1">hl.score.k1</label>
            <input type="text" ng-model="val['hl.score.k1']" name="hl.score.k1" id="hl_score_k1">

            <label for="hl_score_b">hl.score.b</label>
            <input type="text" ng-model="val['hl.score.b']" name="hl.score.b" id="hl_score_b">

            <label for="hl_score_pivot">hl.score.pivot</label>
            <input type="text" ng-model="val['hl.score.pivot']" name="hl.score.pivot" id="hl_score_pivot">

            <label for="hl_bs_language">hl.bs.language</label>
            <input type="text" ng-model="val['hl.bs.language']" name="hl.bs.language" id="hl_bs_language">

            <label for="hl_bs_country">hl.bs.country</label>
            <input type="text" ng-model="val['hl.bs.country']" name="hl.bs.country" id="hl_bs_country">

            <label for="hl_bs_variant">hl.bs.variant</label>
            <input type="text" ng-model="val['hl.bs.variant']" name="hl.bs.variant" id="hl_bs_variant">

            <label for="hl_bs_type">
              hl.bs.type
              <select ng-model="val['hl.bs.type']" name="hl.bs.type" id="hl_bs_type">
                <option ng-selected="selected" value=''>------</option>
                <option value="SENTENCE">SENTENCE</option>
                <option value="SEPARATOR">SEPARATOR</option>
                <option value="WORD">WORD</option>
                <option value="CHARACTER">CHARACTER</option>
                <option value="LINE">LINE</option>
                <option value="WHOLE">WHOLE</option>
              </select>
            </label>

            <label for="hl_bs_separator">hl.bs.separator</label>
            <input type="text" ng-model="val['hl.bs.separator']" name="hl.bs.separator" id="hl_bs_separator">

            <label for="hl_weightMatches" class="checkbox">
              <input type="checkbox" ng-model="val['hl.weightMatches']" name="hl.weightMatches" id="hl_weightMatches" value=true>
              hl.weightMatches
            </label>
          </div>

          <div class="fieldset" ng-show="val['hl.method']=='original'">
            <label for="hl_mergeContiguous" class="checkbox">
              <input type="checkbox" ng-model="val['hl.mergeContiguous']" name="hl.mergeContiguous" id="hl_mergeContiguous">
              hl.mergeContiguous
            </label>

            <label for="hl_maxMultiValuedToExamine">hl.maxMultiValuedToExamine</label>
            <input type="text" ng-model="val['hl.maxMultiValuedToExamine']" name="hl.maxMultiValuedToExamine" id="hl_maxMultiValuedToExamine">

            <label for="hl_maxMultiValuedToMatch">hl.maxMultiValuedToMatch</label>
            <input type="text" ng-model="val['hl.maxMultiValuedToMatch']" name="hl.maxMultiValuedToMatch" id="hl_maxMultiValuedToMatch">

            <label for="hl_formatter">
              hl.formatter
              <select ng-model="val['hl.formatter']" name="hl.formatter" id="hl_formatter">
                <option ng-selected="selected" value="">------</option>
                <option value="simple">simple</option>
              </select>
            </label>

            <label for="hl_fragmenter">
              hl.fragmenter
              <select ng-model="val['hl.fragmenter']" name="hl.fragmenter" id="hl_fragmenter">
                <option ng-selected="selected" value="">------</option>
                <option value="gap">gap</option>
                <option value="regex">regex</option>
              </select>
            </label>

            <label for="hl_regex_slop">hl.regex.slop</label>
            <input type="text" ng-model="val['hl.regex.slop']" name="hl.regex.slop" id="hl_regex_slop">

            <label for="hl_regex_pattern">hl.regex.pattern</label>
            <input type="text" ng-model="val['hl.regex.pattern']" name="hl.regex.pattern" id="hl_regex_pattern">

            <label for="hl_regex_maxAnalyzedChars">hl.regex.maxAnalyzedChars</label>
            <input type="text" ng-model="val['hl.regex.maxAnalyzedChars']" name="hl.regex.maxAnalyzedChars" id="hl_regex_maxAnalyzedChars">

            <label for="hl_preserveMulti" class="checkbox">
              <input type="checkbox" ng-model="val['hl.preserveMulti']" name="hl.preserveMulti" id="hl_preserveMulti">
              hl.preserveMulti
            </label>

            <label for="hl_payloads" class="checkbox">
              <input type="checkbox" ng-model="val['hl.payloads']" name="hl.payloads" id="hl_payloads" value=true>
              hl.payloads
            </label>
          </div>

          <div class="fieldset" ng-show="val['hl.method']=='original' || val['hl.method']=='fastVector'">
            <label for="hl_alternateField">hl.alternateField</label>
            <input type="text" ng-model="val['hl.alternateField']" name="hl.alternateField" id="hl_alternateField">

            <label for="hl_maxAlternateFieldLength">hl.maxAlternateFieldLength</label>
            <input type="text" ng-model="val['hl.maxAlternateFieldLength']" name="hl.maxAlternateFieldLength" id="hl_maxAlternateFieldLength">

            <label for="hl_highlightAlternate" class="checkbox">
              <input type="checkbox" ng-model="val['hl.highlightAlternate']" name="hl.highlightAlternate" id="hl_highlightAlternate" value=true>
              hl.highlightAlternate
            </label>
          </div>

          <div class="fieldset" ng-show="val['hl.method']=='fastVector'">
            <label for="hl_fragListBuilder">hl.fragListBuilder</label>
            <input type="text" ng-model="val['hl.fragListBuilder']" name="hl.fragListBuilder" id="hl_fragListBuilder">

            <label for="hl_fragmentsBuilder">hl.fragmentsBuilder</label>
            <input type="text" ng-model="val['hl.fragmentsBuilder']" name="hl.fragmentsBuilder" id="hl_fragmentsBuilder">

            <label for="hl_boundaryScanner">hl.boundaryScanner</label>
            <input type="text" ng-model="val['hl.boundaryScanner']" name="hl.boundaryScanner" id="hl_boundaryScanner">

            <label for="hl_phraseLimit">hl.phraseLimit</label>
            <input type="text" ng-model="val['hl.phraseLimit']" name="hl.phraseLimit" id="hl_phraseLimit">

            <label for="hl_multiValuedSeparatorChar">hl.multiValuedSeparatorChar</label>
            <input type="text" ng-model="val['hl.multiValuedSeparatorChar']" name="hl.multiValuedSeparatorChar" id="hl_multiValuedSeparatorChar">
          </div>
        </div>
        </div>
      </fieldset>

      <fieldset class="facet optional">
        <legend>
          <label for="facet" class="checkbox" title="Enable faceting.">
            <input type="checkbox" ng-model="val['facet']" name="facet" id="facet">
            facet
          </label>
        </legend>
        <div class="fieldset" ng-show="val['facet']">

          <label for="facet_query">facet.query</label>
          <textarea ng-model="val['facet.query']" name="facet.query" id="facet_query"></textarea>

          <label for="facet_field">facet.field</label>
          <input type="text" ng-model="val['facet.field']" name="facet.field" id="facet_field">

          <label for="facet_prefix">facet.prefix</label>
          <input type="text" ng-model="val['facet.prefix']" name="facet.prefix" id="facet_prefix">

          <label for="facet_contains">facet.contains</label>
          <input type="text" ng-model="val['facet.contains']" name="facet.contains" id="facet_contains">

          <label for="facet_contains_ignoreCase" class="checkbox">
            <input type="checkbox" ng-model="val['facet.contains.ignoreCase']" name="facet.contains.ignoreCase" id="facet_contains_ignoreCase">
            facet.contains.ignoreCase
          </label>

          <label for="facet_limit">facet.limit</label>
          <input type="text" ng-model="val['facet.limit']" name="facet.limit" id="facet_limit">

          <label for="facet_matches">facet.matches</label>
          <input type="text" ng-model="val['facet.matches']" name="facet.matches" id="facet_matches">

          <label for="facet_sort">facet.sort</label>
          <select ng-model="val['facet.sort']" id="facet_sort" name="facet.sort" title="Ordering of the facet field constraints">
            <option ng-selected="selected" value="">------</option>
            <option value="count">count</option>
            <option value="index">index</option>
          </select>

          <label for="facet_mincount">facet.mincount</label>
          <input type="text" ng-model="val['facet.mincount']" name="facet.mincount" id="facet_mincount">

          <label for="facet_missing" class="checkbox">
            <input type="checkbox" ng-model="val['facet.missing']" name="facet.missing" id="facet_missing">
            facet.missing
          </label>

          <label for="json_facet" title="JSON Facet API">
            json.facet <a href="https://solr.apache.org/guide/solr/latest/query-guide/json-facet-api.html" target="_blank" class="help"></a>
          </label>
          <textarea ng-model="val['json.facet']" name="json.facet" id="json_facet" rows="6"></textarea>
        </div>
      </fieldset>

      <fieldset class="spatial optional">
        <legend>
          <label for="spatial" class="checkbox" title="Show spatial options">
            <input type="checkbox" ng-model="val['spatial']" name="spatial" id="spatial">
            spatial
          </label>
        </legend>
        <div class="fieldset" ng-show="val['spatial']">

        <label for="pt">pt</label>
        <input type="text" ng-model="val['pt']" name="pt" id="pt">

        <label for="sfield">sfield</label>
        <input type="text" ng-model="val['sfield']" name="sfield" id="sfield">

        <label for="d">d</label>
        <input type="text" ng-model="val['d']" name="d" id="d">

        </div>
      </fieldset>

      <fieldset class="spellcheck optional">
        <legend>
          <label for="spellcheck" class="checkbox" title="Enable spellchecking.">
            <input type="checkbox" ng-model="val['spellcheck']" name="spellcheck" id="spellcheck">
            spellcheck
          </label>
        </legend>
        <div class="fieldset" ng-show="val['spellcheck']">

        <label for="spellcheck_build" class="checkbox">
          <input type="checkbox" ng-model="val['spellcheck.build']" name="spellcheck.build" id="spellcheck_build" value="true">
          spellcheck.build
        </label>

        <label for="spellcheck_reload" class="checkbox">
          <input type="checkbox" ng-model="val['spellcheck.reload']" name="spellcheck.reload" id="spellcheck_reload" value="true">
          spellcheck.reload
        </label>

        <label for="spellcheck_q">spellcheck.q</label>
        <input type="text" ng-model="val['spellcheck.q']" name="spellcheck.q" id="spellcheck_q">

        <label for="spellcheck_dictionary">spellcheck.dictionary</label>
        <input type="text" ng-model="val['spellcheck.dictionary']" name="spellcheck.dictionary" id="spellcheck_dictionary">

        <label for="spellcheck_count">spellcheck.count</label>
        <input type="text" ng-model="val['spellcheck.count']" name="spellcheck.count" id="spellcheck_count">

        <label for="spellcheck_onlyMorePopular" class="checkbox">
          <input type="checkbox" ng-model="val['spellcheck.onlyMorePopular']" name="spellcheck.onlyMorePopular" id="spellcheck_onlyMorePopular" value="true">
          spellcheck.onlyMorePopular
        </label>

        <label for="spellcheck_extendedResults" class="checkbox">
          <input type="checkbox" ng-model="val['spellcheck.extendedResults']" name="spellcheck.extendedResults" id="spellcheck_extendedResults" value="true">
          spellcheck.extendedResults
        </label>

        <label for="spellcheck_collate" class="checkbox">
          <input type="checkbox" ng-model="val['spellcheck.collate']" name="spellcheck.collate" id="spellcheck_collate" value="true">
          spellcheck.collate
        </label>

        <label for="spellcheck_maxCollations">spellcheck.maxCollations</label>
        <input type="text" ng-model="val['spellcheck.maxCollations']" name="spellcheck.maxCollations" id="spellcheck_maxCollations">

        <label for="spellcheck_maxCollationTries">spellcheck.maxCollationTries</label>
        <input type="text" ng-model="val['spellcheck.maxCollationTries']" name="spellcheck.maxCollationTries" id="spellcheck_maxCollationTries">

        <label for="spellcheck_accuracy">spellcheck.accuracy</label>
        <input type="text" ng-model="val['spellcheck.accuracy']" name="spellcheck.accuracy" id="spellcheck_accuracy">
       </div>
      </fieldset>
      <label for="custom_parameters" title="Raw Query Parameters">
        <a rel="help">Raw Query Parameters</a>
      </label>
      <div class="multiple" id="custom_parameters">
        <div class="row clearfix" ng-repeat="param in rawParams">
          <input type="text" ng-model="param.rawParam" name="rawParamQuery" title="Raw param query.">
          <div class="buttons">
            <a class="rem" ng-click="removeRawParam($index)"><span></span></a>
            <a class="add" ng-click="addRawParam($index)"><span></span></a>
          </div>
        </div>
      </div>

      <label for="json_query" title="JSON Request API">
        JSON Query <a href="https://solr.apache.org/guide/solr/latest/query-guide/json-request-api.html" target="_blank" class="help"></a>
      </label>
      <textarea name="json" ng-model="val['json']" id="json_query" title="JSON Query"></textarea>

      <button type="submit" ng-click="doQuery()">Execute Query</button>
    </form>
  </div>

  <div id="result">
    <div ng-show="response.data" id="response">
      <a id="url" class="address-bar" ng-href="{{url}}">{{hostPortContext}}{{url}}</a>
      <pre class="syntax language-{{lang}}"><code ng-bind-html="response.data | highlight:lang | unsafe"></code></pre>
    </div>
  </div>
</div>
