/*

Licensed to the Apache Software Foundation (ASF) under one or more
contributor license agreements.  See the NOTICE file distributed with
this work for additional information regarding copyright ownership.
The ASF licenses this file to You under the Apache License, Version 2.0
(the "License"); you may not use this file except in compliance with
the License.  You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

*/
#securityPanel
{
  position: relative;
}

#securityPanel .main-col
{
  float: left;
  padding: 7px;
  min-width: 700px;
}

#securityPanel #users h2 { background-image: url( ../../img/ico/users.png ); }
#securityPanel #roles h2 { background-image: url( ../../img/ico/key.png ); }
#securityPanel #permissions h2 { background-image: url( ../../img/ico/lock.png ); }
#securityPanel #authn h2 { background-image: url( ../../img/ico/shield.png ); }

#securityPanel .ref-guide-link
{
  cursor: pointer;
  color: #003eff;
  text-decoration-line: underline;
  text-decoration-color: #003eff;
}

#securityPanel .warning-msg
{
  display: block;
  font-weight: bold;
  margin-bottom: 15px;
}

#securityPanel .external-msg
{
  display: block;
  margin-bottom: 20px;
  margin-top: 20px;
  margin-left: 30px;
}

#securityPanel .error-msg
{
  display: block;
  font-weight: bold;
  color: #c00;
  margin-bottom: 15px;
}

#securityPanel .table-hdr {
  border-bottom: 1px solid #dddddd;
  padding: 3px;
  font-weight: bold;
  text-align: left;
  word-wrap: break-word;
}

#securityPanel .td-name {
  width: 150px;
}

#securityPanel .td-role {
  width: 100px;
}

#securityPanel .td-roles {
  width: 200px;
}

#securityPanel .td-coll {
  width: 120px;
}

#securityPanel .td-path {
  width: 250px;
}

#securityPanel .td-method {
  width: 100px;
}

#securityPanel .td-params {
  width: 200px;
}

#securityPanel .table-data {
  border-bottom: 1px solid #dddddd;
  padding: 3px;
  text-align: left;
  word-wrap: break-word;
  max-width: 450px;
}

#securityPanel .table-warn {
  padding: 3px;
  text-align: left;
  word-wrap: break-word;
  max-width: 90%;
}

#securityPanel tr.odd
{
  background-color: #f8f8f8;
}

#securityPanel #authn
{
  display: block;
}

#securityPanel #user-actions
{
  margin-right: 5px;
  float: right;
}

#securityPanel #perm-actions
{
  margin-right: 5px;
  float: right;
}

#securityPanel #authn form .buttons
{
  margin-top: 10px;
  float: right;
  width: 71%;
}

#securityPanel #authn form button.submit
{
  margin-right: 20px;
}

#securityPanel #authn form button.submit span
{
  background-image: url( ../../img/ico/tick.png );
}

#securityPanel #authn form button.reset span
{
  background-image: url( ../../img/ico/cross.png );
}

#securityPanel #authn #user-dialog
{
  z-index: 100;
  background-color: #fff;
  border: 1px solid #f0f0f0;
  box-shadow: 5px 5px 10px #c0c0c0;
  -moz-box-shadow: 5px 5px 10px #c0c0c0;
  -webkit-box-shadow: 5px 5px 10px #c0c0c0;
  position: absolute;
  padding: 10px;
  width: 350px;
}

#securityPanel #authn #role-dialog
{
  z-index: 100;
  background-color: #fff;
  border: 1px solid #f0f0f0;
  box-shadow: 5px 5px 10px #c0c0c0;
  -moz-box-shadow: 5px 5px 10px #c0c0c0;
  -webkit-box-shadow: 5px 5px 10px #c0c0c0;
  position: absolute;
  padding: 10px;
  width: 350px;
}

#securityPanel #authn #add-permission-dialog
{
  z-index: 100;
  background-color: #fff;
  border: 1px solid #f0f0f0;
  box-shadow: 5px 5px 10px #c0c0c0;
  -moz-box-shadow: 5px 5px 10px #c0c0c0;
  -webkit-box-shadow: 5px 5px 10px #c0c0c0;
  position: absolute;
  top: 190px;
  padding: 10px;
  width: 530px;
}

#securityPanel #authn #add-permission-dialog form label
{
  float: left;
  padding-top: 3px;
  padding-bottom: 3px;
  text-align: right;
  width: 110px;
  margin-right: 6px;
}

#securityPanel #authn #user-dialog form label
{
  float: left;
  padding-top: 3px;
  padding-bottom: 3px;
  text-align: right;
  width: 37%;
  margin-right: 6px;
}

#securityPanel #authn form p {
  padding-bottom: 8px;
}

#securityPanel #add-user span
{
  background-image: url( ../../img/ico/useradd.png );
}

#securityPanel #add-permission
{
  margin-left: 10px;
}

#securityPanel #add-permission span
{
  background-image: url( ../../img/ico/lockplus.png );
}

#securityPanel #authn .validate-error
{
  background-image: url( ../../img/ico/cross.png );
}

#securityPanel #authn .validate-error span
{
  color: #c00;
  font-weight: bold;
  margin-left: 18px;
}

#securityPanel #authn .formMessageHolder {
  display: block;
  margin-top: 7px;
  height: 56px;
  margin-bottom: 7px;
  margin-left: 10px;
}

#securityPanel .form-field {
  margin-top: 7px;
}

#securityPanel #authn .input-text {
  width: 142px;
}

#securityPanel #authn .input-check {
  margin-left: 0px;
  text-align: left;
  width: 25px;
}

#securityPanel #authn #add_perm_path {
  width: 280px;
}

#securityPanel #authn #add_perm_params {
  width: 300px;
}

#securityPanel #authn #add_user_roles {
  width: 148px;
}

#securityPanel #authn #add_perm_roles {
  width: 148px;
}

#securityPanel #authn #predefined {
  width: 172px;
}

#securityPanel #users-content
{
  height: 230px;
  margin-bottom: 20px;
}

#securityPanel #users-table
{
  height: 200px;
  overflow: auto;
}

#securityPanel #roles-content
{
  height: 230px;
  margin-bottom: 20px;
}

#securityPanel #roles-table
{
  height: 200px;
  overflow: auto;
}

#securityPanel #perms-table
{
  max-height: 400px;
  overflow: auto;
}

#securityPanel .help div.help-perm
{
  z-index: 200;
  background-color: #FCF0AD;
  border: 1px solid #f0f0f0;
  box-shadow: 5px 5px 10px #c0c0c0;
  -moz-box-shadow: 5px 5px 10px #c0c0c0;
  -webkit-box-shadow: 5px 5px 10px #c0c0c0;
  position: absolute;
  left: 20px;
  top: 90px;
  padding: 6px;
  width: 420px;
}

#securityPanel .help-anchor
{
  margin-top: 7px;
  margin-left: 18px;
  margin-bottom: 10px;
}

#securityPanel .help-anchor a
{
  color: #003eff;
  text-decoration-line: underline;
  text-decoration-color: #003eff;
}

#securityPanel .help-ico {
  margin-left: 3px;
  margin-top: 3px;
}

#securityPanel .heading {
  display: block;
  font-weight: bold;
  font-size: 12px;
  margin-left: 10px;
  margin-bottom: 10px;
}

#securityPanel .users-left
{
  float: left;
  width: 45%;
  margin-right: 20px;
}

#securityPanel .roles-right
{
  overflow: auto;
}

#securityPanel #user-filters
{
  margin-top: 3px;
  margin-bottom: 10px;
}

#securityPanel #user-filter-type
{
  margin-right: 5px;
}

#securityPanel #user-filter-text
{
  width: 100px;
}

#securityPanel #perm-filters
{
  margin-top: 3px;
  margin-bottom: 10px;
}

#securityPanel #perm-filter-type
{
  margin-right: 5px;
}

#securityPanel #perm-filter-text
{
  width: 100px;
}

#securityPanel #delete-user
{
  margin-left: 15px;
  float: right;
}

#securityPanel #delete-user span
{
  background-image: url( ../../img/ico/cross-button.png );
}

#securityPanel #user-heading {
  display: block;
  padding: 4px;
  margin-bottom: 22px;
}

#securityPanel #role-heading {
  display: block;
  padding: 4px;
  margin-bottom: 22px;
}

#securityPanel #perm-heading {
  display: block;
  padding: 4px;
  margin-bottom: 22px;
}

#securityPanel #delete-perm
{
  margin-left: 15px;
  float: right;
}

#securityPanel #delete-perm span
{
  background-image: url( ../../img/ico/cross-button.png );
}

#securityPanel #role-filters
{
  margin-top: 3px;
  margin-bottom: 10px;
}

#securityPanel #role-filter-type
{
  margin-right: 5px;
}

#securityPanel #role-filter-text
{
  width: 100px;
}

#securityPanel #role-actions
{
  margin-right: 5px;
  float: right;
}

#securityPanel #add-role span
{
  background-image: url( ../../img/ico/keyplus.png );
}

#securityPanel #authn-settings {
  margin-top: 5px;
  margin-bottom: 20px;
}

#securityPanel #plugins {
  display: block;
  margin-bottom: 10px;
}

#securityPanel #authzPlugin {
  margin-left: 40px;
}

#securityPanel #realm-field {
  display: inline;
  width: 150px;
  margin-right: 30px;
}

#securityPanel #block-field {
  display: inline;
  width: 220px;
  margin-right: 30px;
}

#securityPanel #forward-field {
  display: inline;
  width: 220px;
}

#securityPanel #blockUnknownHelp
{
  z-index: 200;
  background-color: #FCF0AD;
  border: 1px solid #f0f0f0;
  box-shadow: 5px 5px 10px #c0c0c0;
  -moz-box-shadow: 5px 5px 10px #c0c0c0;
  -webkit-box-shadow: 5px 5px 10px #c0c0c0;
  position: absolute;
  left: 210px;
  top: 100px;
  padding: 6px;
  width: 380px;
}

#securityPanel #multiAuthBasicHelp
{
  z-index: 200;
  background-color: #FCF0AD;
  border: 1px solid #f0f0f0;
  box-shadow: 5px 5px 10px #c0c0c0;
  -moz-box-shadow: 5px 5px 10px #c0c0c0;
  -webkit-box-shadow: 5px 5px 10px #c0c0c0;
  position: absolute;
  left: 210px;
  top: 70px;
  padding: 6px;
  width: 380px;
}

#securityPanel #forwardCredsHelp
{
  z-index: 200;
  background-color: #FCF0AD;
  border: 1px solid #f0f0f0;
  box-shadow: 5px 5px 10px #c0c0c0;
  -moz-box-shadow: 5px 5px 10px #c0c0c0;
  -webkit-box-shadow: 5px 5px 10px #c0c0c0;
  position: absolute;
  left: 450px;
  top: 100px;
  padding: 6px;
  width: 380px;
}

#securityPanel #authn-content
{
  margin-top: 10px;
  height: 80px;
  overflow: auto;
}

#securityPanel #authn #role-dialog form label
{
  float: left;
  padding-top: 3px;
  padding-bottom: 3px;
  text-align: right;
  width: 37%;
  margin-right: 6px;
}

#securityPanel #add_perm_custom
{
  margin-left: 5px;
  display: inline;
}

#securityPanel #add_perm_name {
  width: 125px;
}

#securityPanel #perm-select {
  margin-top: 12px;
  margin-bottom: 15px;
}

#securityPanel .help div.help-index
{
  z-index: 200;
  background-color: #FCF0AD;
  border: 1px solid #f0f0f0;
  box-shadow: 5px 5px 10px #c0c0c0;
  -moz-box-shadow: 5px 5px 10px #c0c0c0;
  -webkit-box-shadow: 5px 5px 10px #c0c0c0;
  position: absolute;
  left: 20px;
  top: 90px;
  padding: 6px;
  width: 380px;
}

#securityPanel #param-rows
{
  display: block;
  height: 100px;
  max-height: 100px;
  overflow: auto;
}

#securityPanel .row
{
  display: block;
  margin-bottom: 5px;
  margin-right: 100px;
}

#securityPanel .row .param-name
{
  display: inline;
  float: left;
  width: 90px;
}

#securityPanel .row .param-value
{
  display: inline;
  width: 140px;
}

#securityPanel .row .param-buttons
{
  float: right;
  width: 40px;
}

#securityPanel .row a
{
  background-position: 50% 50%;
  display: block;
  height: 25px;
  width: 49%;
}

#securityPanel .row a.add
{
  background-image: url( ../../img/ico/plus-button.png );
  float: right;
}

#securityPanel .row a.rem
{
  background-image: url( ../../img/ico/minus-button.png );
  float: left;
}

#securityPanel .error-dialog
{
  z-index: 200;
  background-color: #f0f0f0;
  border: 1px solid #c00;
  box-shadow: 5px 5px 10px #c0c0c0;
  -moz-box-shadow: 5px 5px 10px #c0c0c0;
  -webkit-box-shadow: 5px 5px 10px #c0c0c0;
  position: absolute;
  left: 350px;
  top: 95px;
  padding: 20px;
  width: 450px;
}

#securityPanel #error-dialog #error-dialog-buttons {
  float: right;
}

#securityPanel #error-dialog .error-button {
  margin-right: 15px;
}

#securityPanel #error-dialog .error-button span
{
  background-image: url( ../../img/ico/tick.png );
}

#securityPanel #error-dialog-note {
  color: #c00;
  font-weight: bold;
  margin-bottom: 15px;
}

#securityPanel #error-dialog-details {
  min-height: 80px;
  margin-bottom: 15px;
}

#securityPanel #authnPlugin {
  margin-left: 20px;
}

#securityPanel .editable {
  cursor: pointer;
}